% --------- Principal Component Analysis --------- %

%% Load data
load data_33rpz_pca.mat
im_size = size(trn_data.images(:,:,1));

%% Prepare data for PCA
[x x_mean] = prepare_data(trn_data.images);
[x_tst x_mean_tst] = prepare_data(tst_data.images);

%% Principal component orthogonal basis
[y lambdas] = pca_basis(x);

%% Display eigenvectors (eigenfaces)
disp_eigenfaces(y, im_size);

%% Plot the cumulative sum of eigenvalues
sum_eigenvalues_graph(lambdas);

%% Experiments with different m values
sel_image = 1;
num_comp = size(y,2);
z_im = zeros([im_size 1 num_comp]);
class_error = zeros(1, num_comp);
% Prepare labels
names_unique = unique(trn_data.names);
[~, labels_tst_gt] = ismember(tst_data.names, names_unique);

for m = 1:num_comp

    % Compact representation of the images
    w = compact_representation(x, y, m);

    % Reconstruct the images (approximation)
    z = reconstruct_images(w, y, x_mean);
    
    % Store images
    z_im(:,:,1,m) = reshape(z(:,sel_image),im_size);
    
    % NN classifier
    [labels_tst] = classify_nn_pca(tst_data.images, m);
    
    % Classification error
    class_error(m) = sum(labels_tst_gt~=labels_tst)/numel(labels_tst_gt);
    
end
    
%% Display the images
figure, montage(uint8(z_im));

%% Plot the classification error vs the number of components
figure, plot(class_error), grid on;
xlabel 'Number of components'
ylabel 'Classification error'