% 
% [x x_mean] = prepare_data(images)
% 
% Function for vectorize the stack of images, compute the mean image and
% substract it from the set of images
%
% Input:
%       images - Stack of images, of size [width, height, number_of_images]
% Output:
%       x - Vectorized and centered images, of size [width*height, number_of_images]
%       x_mean - Mean veactorized image, of size [width*height, 1]
%

function [x x_mean] = prepare_data(images)

    % Vectorize images
    x = double(reshape(images, size(images,1)*size(images,2),[]));
    
    % Compute mean vector
    x_mean = mean(x,2);
    
    % Substract mean
    x = x - repmat(x_mean, [1,size(x,2)]);

end